package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.CouponChannel;
import com.chilunyc.fumao.place.request.couponChannel.CouponChannelEditRequest;
import com.chilunyc.fumao.place.request.couponChannel.CouponChannelPageRequest;
import com.chilunyc.fumao.place.service.CouponChannelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "优惠券渠道")
@RestController
@RequestMapping("/place/coupon/channel")
class CouponChannelController {

    @Autowired
    CouponChannelService couponChannelService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<CouponChannel>> page(@RequestBody CouponChannelPageRequest request) {
        Page<CouponChannel> page = couponChannelService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<CouponChannel> info(@PathVariable Long id) {
        CouponChannel couponChannelResponse = couponChannelService.find(id);
        return JsonResponse.success(couponChannelResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "CouponChannel")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(PlaceAdmin placeAdmin, @RequestBody @Valid CouponChannelEditRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        couponChannelService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
        couponChannelService.remove(request);
        return JsonResponse.success();
    }


}