package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.common.util.MapBuilder;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.Coupon;
import com.chilunyc.fumao.place.model.CouponChannel;
import com.chilunyc.fumao.place.request.coupon.CouponEditRequest;
import com.chilunyc.fumao.place.request.coupon.CouponPageRequest;
import com.chilunyc.fumao.place.service.CouponChannelService;
import com.chilunyc.fumao.place.service.CouponService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 *
 */
@Log4j
@Api(description = "优惠券")
@RestController
@RequestMapping("/place/coupon")

@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceCouponExp)
class CouponController {

    @Autowired
    CouponService couponService;

    @Autowired
    CouponChannelService couponChannelService;

    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<Coupon>> page(PlaceAdmin placeAdmin, @RequestBody CouponPageRequest request) {
        Page<Coupon> page = couponService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<Map> info(@PathVariable Long id) {
        Coupon couponResponse = couponService.find(id);
        List<CouponChannel> couponChannelList = couponChannelService.findByCouponId(id, true);
        return JsonResponse.success(
                MapBuilder
                        .builder()
                        .put("coupon", couponResponse)
                        .put("couponCateList", couponChannelList)
                        .getMap()
        );
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "Coupon")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(PlaceAdmin placeAdmin, @RequestBody @Valid CouponEditRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        Coupon coupon = couponService.edit(request);
        return JsonResponse.success(coupon);
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest<Long> request) {
        couponService.remove(request);
        return JsonResponse.success();
    }

    @RequestMapping(value = "/cate", method = RequestMethod.GET)
    JsonResponse cates() {
        return JsonResponse.success(couponService.cates());
    }

}