package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.Customer;
import com.chilunyc.fumao.place.request.customer.CustomerEditRequest;
import com.chilunyc.fumao.place.request.customer.CustomerPageRequest;
import com.chilunyc.fumao.place.service.CustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "顾客")
@RestController
@RequestMapping("/place/customer")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceCustomerExp)
class CustomerController {

    @Autowired
    CustomerService customerService;

    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<Customer>> page(PlaceAdmin placeAdmin, @RequestBody CustomerPageRequest request) {
        Page<Customer> page = customerService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<Customer> info(PlaceAdmin placeAdmin, @PathVariable Long id) {
        Customer customerResponse = customerService.find(id);
        return JsonResponse.success(customerResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "Customer")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(PlaceAdmin placeAdmin, @RequestBody @Valid CustomerEditRequest request) {
        customerService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(PlaceAdmin placeAdmin, @RequestBody @Valid IdsRequest<Long> request) {
        customerService.remove(request);
        return JsonResponse.success();
    }

    @RequestMapping(value = "/find/mobile/{mobile}")
    JsonResponse findByMobile(@PathVariable String mobile) {
        return JsonResponse.success(customerService.findByMobile(mobile));
    }
}