package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.bi.model.BiCustomerRegister;
import com.chilunyc.fumao.bi.model.BiTrade;
import com.chilunyc.fumao.bi.service.BiCustomerLoginService;
import com.chilunyc.fumao.bi.service.BiCustomerRegisterService;
import com.chilunyc.fumao.bi.service.BiTradeService;
import com.chilunyc.fumao.common.request.TimeRangeRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.response.KeyValue;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.service.service.CustomerDashboardService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "顾客")
@RestController
@RequestMapping("/place/customer/dashboard")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceCustomerExp)
class CustomerDashboardController {

    @Autowired
    CustomerDashboardService customerDashboardService;

    @Autowired
    BiCustomerRegisterService biCustomerRegisterService;

    @Autowired
    BiCustomerLoginService biCustomerLoginService;

    @Autowired
    BiTradeService biTradeService;

    @ApiOperation("今日新增会员")
    @RequestMapping(value = "/add", method = RequestMethod.GET)
    JsonResponse add() {
        return JsonResponse.success(customerDashboardService.add());
    }


    @ApiOperation("今日会员消费金额")
    @RequestMapping(value = "/money", method = RequestMethod.GET)
    JsonResponse money() {
        return JsonResponse.success(customerDashboardService.money());
    }

    @RequestMapping(value = "/chart/register", method = RequestMethod.POST)
    JsonResponse<List<BiCustomerRegister>> chartRegister(@RequestBody TimeRangeRequest request) {
        return JsonResponse.success(
                biCustomerRegisterService.range(request.getTimeRange())
        );
    }

    @RequestMapping(value = "/chart/active", method = RequestMethod.POST)
    JsonResponse<List<KeyValue>> chartActive(@RequestBody TimeRangeRequest request) {
        return JsonResponse.success(
                biCustomerLoginService.range(request.getTimeRange())
        );
    }

    @RequestMapping(value = "/chart/trade", method = RequestMethod.POST)
    JsonResponse<List<BiTrade>> chartTrade(@RequestBody TimeRangeRequest request) {
        return JsonResponse.success(
                biTradeService.range(request.getTimeRange())
        );
    }
}