package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.MerchantAdmin;
import com.chilunyc.fumao.place.request.merchantAdmin.MerchantAdminEditRequest;
import com.chilunyc.fumao.place.request.merchantAdmin.MerchantAdminPageRequest;
import com.chilunyc.fumao.place.service.MerchantAdminService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "商户管理员")
@RestController
@RequestMapping("/place/merchant/admin")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceMerchantExp)
class MerchantAdminController {

    @Autowired
    MerchantAdminService merchantAdminService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<MerchantAdmin>> page(@RequestBody MerchantAdminPageRequest request) {
        Page<MerchantAdmin> page = merchantAdminService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<MerchantAdmin> info(@PathVariable Long id) {
        MerchantAdmin merchantAdminResponse = merchantAdminService.find(id);
        return JsonResponse.success(merchantAdminResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "MerchantAdmin")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(@RequestBody @Valid MerchantAdminEditRequest request) {
        merchantAdminService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest<Long> request) {
        merchantAdminService.remove(request);
        return JsonResponse.success();
    }

    @RequestMapping(value = "/find/all", method = RequestMethod.GET)
    JsonResponse<List<MerchantAdmin>> all(MerchantAdminPageRequest request) {
        return JsonResponse.success(merchantAdminService.all(request));
    }

    @ApiOperation(value = "重置密码")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/reset/password/{id}", method = RequestMethod.GET)
    JsonResponse resetPassword(PlaceAdmin placeAdmin, @PathVariable Long id) {
        merchantAdminService.resetPassword(id);
        log.info(String.format("商场管理员[ %s ]重置密码 => [ %s ]", placeAdmin.getId(), id));
        return JsonResponse.success();
    }
}