package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminAddRequest;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminEditRequest;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminPageRequest;
import com.chilunyc.fumao.company.service.PlaceAdminService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "商场管理员")
@RestController
@RequestMapping("/place/admin")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceAccountExp)
class PlaceAdminController {

    @Autowired
    PlaceAdminService placeAdminService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<PlaceAdmin>> page(PlaceAdmin placeAdmin, @RequestBody PlaceAdminPageRequest request) {
        request.setCompanyId(placeAdmin.getPlaceId());
        Page<PlaceAdmin> page = placeAdminService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<PlaceAdmin> info(@PathVariable Long id) {
        PlaceAdmin placeAdminResponse = placeAdminService.find(id);
        return JsonResponse.success(placeAdminResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PlaceAdmin")
    })
    @RequestMapping(value = "/add", method = RequestMethod.POST)
    JsonResponse add(PlaceAdmin placeAdmin, @RequestBody @Valid PlaceAdminAddRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        request.setCompanyId(placeAdmin.getCompanyId());
        PlaceAdmin add = placeAdminService.add(request);
        return JsonResponse.success(add);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PlaceAdmin")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(PlaceAdmin placeAdmin, @RequestBody @Valid PlaceAdminEditRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        request.setCompanyId(placeAdmin.getCompanyId());
        placeAdminService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest<Long> request) {
        placeAdminService.remove(request);
        return JsonResponse.success();
    }


    @ApiOperation(value = "重置密码")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/reset/password/{id}", method = RequestMethod.GET)
    JsonResponse resetPassword(PlaceAdmin companyAdmin, @PathVariable Long id) {
        placeAdminService.resetPassword(id, companyAdmin.getCompanyId());
        log.info(String.format("商场管理员[ %s ]重置密码 => [ %s ]", companyAdmin.getId(), id));
        return JsonResponse.success();
    }

    @RequestMapping(value = "/find/all", method = RequestMethod.POST)
    JsonResponse<List<PlaceAdmin>> all(PlaceAdmin placeAdmin, @RequestBody PlaceAdminPageRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        return JsonResponse.success(placeAdminService.all(request));
    }
}