package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.PointTransaction;
import com.chilunyc.fumao.place.request.pointTransaction.PointTransactionPaddedRequest;
import com.chilunyc.fumao.place.request.pointTransaction.PointTransactionPageRequest;
import com.chilunyc.fumao.place.service.PointTransactionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "积分")
@RestController
@RequestMapping("/place/point/transaction")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceCustomerExp)
class PointTransactionController {

    @Autowired
    PointTransactionService pointTransactionService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<PointTransaction>> page(@RequestBody PointTransactionPageRequest request) {
        Page<PointTransaction> page = pointTransactionService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<PointTransaction> info(@PathVariable Long id) {
        PointTransaction pointTransactionResponse = pointTransactionService.find(id);
        return JsonResponse.success(pointTransactionResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PointTransaction")
    })
    @RequestMapping(value = "/padded", method = RequestMethod.POST)
    JsonResponse padded(PlaceAdmin placeAdmin, @RequestBody @Valid PointTransactionPaddedRequest request) {
        request.setAdminId(placeAdmin.getId());
        request.setPlaceId(placeAdmin.getPlaceId());
        pointTransactionService.padded(request);
        return JsonResponse.success();
    }


}