package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.AssignsRequest;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.place.model.Shop;
import com.chilunyc.fumao.place.request.shop.ShopEditRequest;
import com.chilunyc.fumao.place.request.shop.ShopPageRequest;
import com.chilunyc.fumao.place.service.ShopService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "商铺")
@RestController
@RequestMapping("/place/shop")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceMerchantExp)
class ShopController {

    @Autowired
    ShopService shopService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<Shop>> page(PlaceAdmin placeAdmin, @RequestBody ShopPageRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        Page<Shop> page = shopService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<Shop> info(@PathVariable Long id) {
        Shop shopResponse = shopService.find(id);
        return JsonResponse.success(shopResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "Shop")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(PlaceAdmin placeAdmin, @RequestBody @Valid ShopEditRequest request) {
        request.setPlaceId(placeAdmin.getPlaceId());
        shopService.edit(request);
        return JsonResponse.success();
    }

    @RequestMapping(value = "/assign", method = RequestMethod.POST)
    JsonResponse assignToMerchant(@RequestBody @Valid AssignsRequest<Long> request) {
        shopService.assign(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest<Long> request) {
        shopService.remove(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "所有")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/all", method = RequestMethod.GET)
    JsonResponse<List<Shop>> all(ShopPageRequest request) {
        List<Shop> result = shopService.all(request);
        return JsonResponse.success(result);
    }

    @ApiOperation(value = "解绑商户")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/unbind/merchant/{shopId}", method = RequestMethod.GET)
    JsonResponse unbindMerchant(@PathVariable Long shopId){
        shopService.unbindMerchant(shopId);
        return JsonResponse.success();
    }

}