package com.chilunyc.fumao.api.system;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.CompanyAdmin;
import com.chilunyc.fumao.company.request.companyAdmin.CompanyAdminEditRequest;
import com.chilunyc.fumao.company.request.companyAdmin.CompanyAdminPageRequest;
import com.chilunyc.fumao.company.service.CompanyAdminService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "集团管理员")
@RestController
@RequestMapping("/system/company/admin")
@PreAuthorize(AuthRoles.SystemAdminExp)
class CompanyAdminController {

    @Autowired
    CompanyAdminService companyAdminService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<CompanyAdmin>> page(@RequestBody CompanyAdminPageRequest request) {
        Page<CompanyAdmin> page = companyAdminService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<CompanyAdmin> info(@PathVariable Long id) {
        CompanyAdmin companyAdminResponse = companyAdminService.find(id);
        return JsonResponse.success(companyAdminResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "CompanyAdmin")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(@RequestBody @Valid CompanyAdminEditRequest request) {
        companyAdminService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest<Long> request) {
        companyAdminService.remove(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "所有")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/all", method = RequestMethod.GET)
    JsonResponse<List<CompanyAdmin>> all(CompanyAdminPageRequest request) {
        List<CompanyAdmin> result = companyAdminService.all(request);
        return JsonResponse.success(result);
    }

}