package com.chilunyc.fumao.api.system;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.PlaceFloor;
import com.chilunyc.fumao.company.request.placeFloor.PlaceFloorEditRequest;
import com.chilunyc.fumao.company.request.placeFloor.PlaceFloorPageRequest;
import com.chilunyc.fumao.company.service.PlaceFloorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "商场楼层")
@RestController
@RequestMapping("/system/place/floor")
@PreAuthorize(AuthRoles.SystemAdminExp)
class PlaceFloorController {

    @Autowired
    PlaceFloorService placeFloorService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find/all", method = RequestMethod.POST)
    JsonResponse<List<PlaceFloor>> all(@RequestBody PlaceFloorPageRequest request) {
        List<PlaceFloor> page = placeFloorService.all(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<PlaceFloor> info(@PathVariable Long id) {
        PlaceFloor placeFloorResponse = placeFloorService.find(id);
        return JsonResponse.success(placeFloorResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PlaceFloor")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(@RequestBody @Valid PlaceFloorEditRequest request) {
        placeFloorService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
        placeFloorService.remove(request);
        return JsonResponse.success();
    }


}