package com.chilunyc.fumao.api.system;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.ShopApply;
import com.chilunyc.fumao.company.request.shopApply.ShopApplyEditRequest;
import com.chilunyc.fumao.company.request.shopApply.ShopApplyPageRequest;
import com.chilunyc.fumao.company.service.ShopApplyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "商铺申请")
@RestController
@RequestMapping("/system/shop/apply")
@PreAuthorize(AuthRoles.SystemAdminExp)
class ShopApplyController {

    @Autowired
    ShopApplyService shopApplyService;

    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<ShopApply>> page(@RequestBody ShopApplyPageRequest request) {
        Page<ShopApply> page = shopApplyService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<ShopApply> info(@PathVariable Long id) {
        ShopApply shopApplyResponse = shopApplyService.find(id);
        return JsonResponse.success(shopApplyResponse);
    }


    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
        shopApplyService.remove(request);
        return JsonResponse.success();
    }

}