package com.chilunyc.fumao.api.system;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.system.model.SystemAdmin;
import com.chilunyc.fumao.system.request.systemAdmin.SystemAdminEditRequest;
import com.chilunyc.fumao.system.request.systemAdmin.SystemAdminPageRequest;
import com.chilunyc.fumao.system.service.SystemAdminService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "系统管理员")
@RestController
@RequestMapping("/system/admin")
@PreAuthorize(AuthRoles.SystemAdminExp)
class SystemAdminController {

    @Autowired
    SystemAdminService systemAdminService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<SystemAdmin>> page(@RequestBody SystemAdminPageRequest request) {
        Page<SystemAdmin> page = systemAdminService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<SystemAdmin> info(@PathVariable Long id) {
        SystemAdmin systemAdminResponse = systemAdminService.find(id);
        return JsonResponse.success(systemAdminResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "SystemAdmin")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(@RequestBody @Valid SystemAdminEditRequest request) {
        systemAdminService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
        systemAdminService.remove(request);
        return JsonResponse.success();
    }


}