package com.chilunyc.fumao.config.web.filter;

import com.chilunyc.fumao.common.context.Request;
import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.db.datasource.DynamicDataSourceHolder;
import org.springframework.stereotype.Component;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 *  on 2018/7/26.
 */
@Component
public class DBRouteFilter extends OncePerRequestFilter {


    @Override
    protected void doFilterInternal(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, FilterChain filterChain) throws ServletException, IOException {
        try {
            String servletPath = httpServletRequest.getServletPath();
            String prefix = org.apache.commons.lang3.StringUtils.substringBetween(servletPath, "/", "/");
            Request request = RequestHolder.get();
            if (request != null && request.getJwtValue() != null) {
                Long cid = null;
                switch (prefix) {
                    case "system":
                        break;

                    // 从jwt中获取
                    case "company":
                    case "place":
                        cid = request.getJwtValue().get("cid", Long.class);
                        break;

                    // 从url中获取
                    default:
                        cid = Long.parseLong(prefix);
                        break;
                }
                if (cid != null) {
                    DynamicDataSourceHolder.set(cid.toString());
                }
            }
            filterChain.doFilter(httpServletRequest, httpServletResponse);
        } finally {
            DynamicDataSourceHolder.remove();
        }
    }
}
