package com.chilunyc.fumao.common.aop.retry;

import com.chilunyc.fumao.common.aop.BaseAop;
import lombok.extern.log4j.Log4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.stereotype.Component;

/**
 *
 */
@Log4j
@Component
@Aspect
public class RetryAop extends BaseAop {

    @Around("@annotation(com.chilunyc.fumao.common.aop.retry.Retry)")
    Object execute(ProceedingJoinPoint joinPoint) throws Throwable {
        Retry annotation = getAnnotation(joinPoint, Retry.class);
        int times = 0;
        Object result = null;
        while (times++ < annotation.maxTimes()) {
            try {
                result = joinPoint.proceed();
            } catch (Exception e) {
                log.error(String.format("重试, 场景[%s], 参数[%s], 次数[%s] => 失败[%s]", annotation.scene(), joinPoint.getArgs(), times, e.getMessage()));
            }
        }
        return result;
    }
}
