package com.chilunyc.fumao.common.lbs.service;

import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.lbs.config.LBSProperties;
import com.chilunyc.fumao.common.lbs.model.LBSPoi;
import com.chilunyc.fumao.common.lbs.request.LBSPoiRequest;
import com.chilunyc.fumao.common.util.http.service.HttpClient;
import com.chilunyc.fumao.common.util.http.service.HttpParams;
import com.chilunyc.fumao.common.util.http.service.result.ResultExecute;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.log4j.Log4j;
import okhttp3.Request;
import okhttp3.Response;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.stereotype.Service;
import org.springframework.util.StopWatch;

import java.util.ArrayList;
import java.util.List;

/**
 *
 */
@Log4j
@Service
public class LBSService implements ResultExecute<String> {

    @Autowired
    private HttpClient httpClient;

    @Autowired
    private LBSProperties lbsProperties;

    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * @param request
     * @return
     */
    public Page<LBSPoi> findPoi(LBSPoiRequest request) {
        HttpParams httpParams = HttpParams.get("http://api.map.baidu.com/place/v2/search");
        httpParams
                .put("query", request.getQuery())
                .put("region", request.getCity())
                .put("page_size", request.getSize())
                .put("page_num", request.getPageI())
                .put("output", "json")
                .put("ak", lbsProperties.getAk());
        String body = httpClient.execute(httpParams, this);
        JSONObject object = JSON.parseObject(body);
        JSONArray jsonArray = object.getJSONArray("results");
        int total = object.getIntValue("total");
        List<LBSPoi> pois = new ArrayList<>(jsonArray.size());
        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject jsonObject = jsonArray.getJSONObject(i);
            LBSPoi lbsPoi = jsonObject.toJavaObject(LBSPoi.class);
            lbsPoi.setLocation(jsonObject.getJSONObject("location").toJavaObject(LBSPoi.Location.class));
            pois.add(lbsPoi);
        }
        return new PageImpl<>(pois, request.getPage(), total);
    }

    @Override
    public String toBody(Response response, Request request, StopWatch stopWatch) throws Exception {
        String string = response.body().string();
        if (StringUtils.contains(string, "\"status\":0")) {
            return string;
        }
        log.error(string);
        throw new SystemException("000008");
    }
}
