package com.chilunyc.fumao.common.log.service;

import com.chilunyc.fumao.common.log.model.Event;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.repository.EventRepository;
import com.chilunyc.fumao.common.context.Request;
import com.alibaba.fastjson.JSON;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Log4j
@Service
@Transactional
@Async
public class EventService {

    @Autowired
    private EventRepository eventRepository;


    public void add(Request request, EventTarget target, EventType type, String targetId) {
        add(request, target, type, targetId, null);
    }

    public void add(Request request, EventType type, String targetId, Object content) {
        add(request, EventTarget.None, type, targetId, content);
    }

    public void add(Request request, EventType type, Object content) {
        add(request, EventTarget.None, type, null, content);
    }

    public void add(Request request, EventTarget target, EventType type) {
        add(request, target, type, null, null);
    }

    /**
     * @param request
     * @param target
     * @param type
     * @param targetId
     * @param content
     */
    public void add(Request request, EventTarget target, EventType type, Serializable targetId, Object content) {
        String contentStr = "";
        if (content != null && !content.getClass().isAssignableFrom(String.class)) {
            contentStr = JSON.toJSONString(content);
        } else if (content != null) {
            contentStr = content.toString();
        }
        String operator = "";
        if (request != null && request.getLoginUser() != null) {
            operator = request.getLoginUser().getId().toString();
        }
        Event build = Event
                .builder()
                .target(target)
                .ip(request == null ? "" : request.getIp())
                .type(type)
                .operator(operator)
                .targetId(targetId != null ? target.toString() : null)
                .content(contentStr)
                .createTime(new Date())
                .build();
        eventRepository.save(build);
    }
}
