package com.chilunyc.fumao.common.sms.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.sms.config.SmsProperties;
import com.chilunyc.fumao.common.sms.model.Sms;
import com.chilunyc.fumao.common.sms.repository.SmsRepository;
import com.chilunyc.fumao.common.sms.request.SmsCheckRequest;
import com.chilunyc.fumao.common.sms.request.SmsSendRequest;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.concurrent.TimeUnit;

/**
 *
 */
@Service
@Transactional
public class SmsService {

    @Autowired
    private SmsRepository smsRepository;

    @Autowired
    private SmsProperties smsProperties;

    @Autowired
    private EventService eventService;

    /**
     * @param request
     */
    @Transactional
    public void send(SmsSendRequest request) {
        //1. 取最后一次发送的短信
        Sms last = smsRepository.findFirstByMobileOrderByCreateTimeDesc(request.getMobile());
        if (last != null
                && TimeUnit.SECONDS.convert(new Date().getTime() - last.getCreateTime().getTime(), TimeUnit.MILLISECONDS) < 60) {
            throw new SystemException("300010");
        }

//        //2. 发送短信
//        Map<String, Object> map = MapBuilder
//                .builder()
//                .put("code", request.getContent())
//                .put("product", smsProperties.getSignName())
//                .getMap();
//        JsonResponse msgId = aliyunSender.send(request.getType().getTemplate(), request.getMobile(), map);
//        if (StringUtils.isNotBlank(msgId.getError())) {
//            throw new SystemException("300011", new Object[]{msgId.getError()});
//        }

        //3. 把所有该手机的可用的sms全部设置为不可用
        smsRepository.disabled(request.getMobile(), request.getType(), "再次发送短信");

        //3. 存储
        Sms sms = Sms
                .builder()
                .type(request.getType())
                .isCheck(false)
                .mobile(request.getMobile())
                .content(request.getContent())
                .build();
//        sms.setId(msgId.getData().toString());
        sms.setCheckCount(0);
        sms.setCreateTime(new Date());
        sms.setExpiredTime(new Date(sms.getCreateTime().getTime() + 5 * 1000 * 60));
        smsRepository.save(sms);
        eventService.add(RequestHolder.get(), EventTarget.None, EventType.SendMsg, request.getMobile());
    }

    /**
     * @param request
     */
    @Transactional(noRollbackFor = Exception.class)
    public void check(SmsCheckRequest request) {
        Sms one = smsRepository.findOne(QueryBuilder.build(request));
        if (one == null || (one != null && one.getIsCheck())) {
            throw new SystemException("300012");
        }
        // 过期
        else if (one.getExpiredTime().before(new Date())) {
            one.setIsCheck(true);
            one.setMark("验证时效");
            smsRepository.save(one);
            throw new SystemException("300012");
        }
        // 验证通过
        else if (StringUtils.equalsIgnoreCase(one.getContent(), request.getCode())) {
            one.setIsCheck(true);
            one.setMark("校验成功");
            smsRepository.save(one);
        }
        // 次数过多
        else if (one.getCheckCount() > 2) {
            one.setIsCheck(true);
            one.setMark("尝试次数过多");
            smsRepository.save(one);
            throw new SystemException("300012");
        }
        // 验证错误
        else {
            one.setCheckCount(one.getCheckCount() + 1);
            smsRepository.save(one);
            throw new SystemException("300012");
        }
    }
}
