package com.chilunyc.fumao.common.util.excel;

import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.WorkbookFactory;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.*;

/**
 * 80347471@qq.com
 */
public class ExcelHelper {


    public <T> List<T> read(InputStream inputStream, Class<T> tClass) throws Exception {
        return read(inputStream, tClass, 0);
    }

    public <T> List<T> read(InputStream inputStream, Class<T> tClass, int sheetIndex) throws Exception {
        Workbook workbook = null;
        List<T> result = new ArrayList<>();
        try {
            workbook = WorkbookFactory.create(inputStream);
            Sheet sheet = workbook.getSheetAt(sheetIndex);
            ExcelEntityDescription entityDescription = new ExcelEntityDescription(tClass);
            int lastRowNum = sheet.getLastRowNum();
            for (int rowIndex = 0; rowIndex <= lastRowNum; rowIndex++) {
                T entity = (T) entityDescription.read(sheet.getRow(rowIndex), rowIndex);
                if (entity != null) {
                    result.add(entity);
                }
            }
        } finally {
            if (workbook != null) {
                workbook.close();
            }
        }
        return result;
    }

    public void write(List dataList, Class dataClass, OutputStream stream) throws Exception {
        write(
                Collections.singletonMap("sheet0", dataList),
                Collections.singletonList(dataClass),
                stream
        );
    }

    public void write(Map<String, List> sheetDataListMap, List<Class> dataClassList, OutputStream stream) throws Exception {
        XSSFWorkbook workbook = new XSSFWorkbook();
        Set<String> sheetNameSet = sheetDataListMap.keySet();
        int sheetIndex = 0;
        for (String sheetName : sheetNameSet) {
            List sheetDataList = sheetDataListMap.get(sheetName);
            Class sheetDataClass = dataClassList.get(sheetIndex);

            //
            ExcelEntityDescription entityDescription = new ExcelEntityDescription(sheetDataClass);
            XSSFSheet sheet = workbook.createSheet(sheetName);

            //
            entityDescription.writeHead(sheet);
            for (int i = 0; i < sheetDataList.size(); i++) {
                entityDescription.writeEntity(sheet, sheetDataList.get(i), i);
            }
            entityDescription.writeFoot(sheet);

            //
            sheetIndex++;
        }
        workbook.write(stream);
    }

}
