package com.chilunyc.fumao.common.util.jpa;

import com.chilunyc.fumao.common.util.jpa.generator.SnowflaskGenerator;
import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.HibernateException;
import org.hibernate.MappingException;
import org.hibernate.engine.spi.SessionImplementor;
import org.hibernate.id.Configurable;
import org.hibernate.id.IdentifierGenerator;
import org.hibernate.service.ServiceRegistry;
import org.hibernate.type.Type;

import java.io.Serializable;
import java.util.Date;
import java.util.Properties;
import java.util.UUID;

/**
 *
 */
public class CustomIdentifierGenerator implements IdentifierGenerator, Configurable {

    private String type;
    private Properties props;
    private String entityName;

    private SnowflaskGenerator snowflaskGenerator = new SnowflaskGenerator(1L);

    @Override
    public void configure(Type type, Properties params, ServiceRegistry serviceRegistry) throws MappingException {
        this.type = params.get("type").toString().toLowerCase();
        this.props = params;
        entityName = params.getProperty(ENTITY_NAME);
    }

    @Override
    public Serializable generate(SessionImplementor session, Object object) throws HibernateException {
        Serializable id = session
                .getEntityPersister(entityName, object)
                .getIdentifier(object, session);
        if (id != null && StringUtils.isNotBlank(id.toString())) {
            return id;
        }
        switch (type) {
            case "number":
                return snowflaskGenerator.generate();
            case "datetime":
                return DateFormatUtils.format(new Date(), "yyyyMMddHHmmss");
            default:
                String uuid = UUID.randomUUID().toString().replaceAll("-", "");
                return uuid;
        }
    }
}
