package com.chilunyc.fumao.common.util.jwt;

import com.chilunyc.fumao.common.context.LoginUser;
import com.chilunyc.fumao.common.exception.SystemException;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

/**
 *
 */
@Component
public class JwtUtils implements ApplicationContextAware {

    private static SignatureAlgorithm signatureAlgorithm = SignatureAlgorithm.HS512;

    private static StringRedisTemplate redisTemplate;

    public enum T {
        System(DigestUtils.md5Hex("System")),
        Company(DigestUtils.md5Hex("Company")),
        Market(DigestUtils.md5Hex("Market")),
        APP_C(DigestUtils.md5Hex("APP_C")),
        APP_B(DigestUtils.md5Hex("APP_B")),;
        private String key;

        T(String key) {
            this.key = key;
        }
    }

    /**
     * @param jwtToken
     * @return
     */
    public static Claims decode(JwtUtils.T t, String jwtToken) {
        try {
            if (StringUtils.isBlank(jwtToken)) {
                throw new RuntimeException();
            }
//            String body = jwtToken.split("\\.")[1];
//            String s = jodd.util.Base64.decodeToString(body);
//            Map m = JSON.parseObject(s);
//            String key = redisTemplate.boundValueOps(t.name() + m.get("sub")).get();
            Claims claims = Jwts.parser().setSigningKey(t.key).parseClaimsJws(jwtToken).getBody();
            return claims;
        } catch (Exception e) {
            throw new SystemException("000002");
        }
    }

    /**
     * @param user
     * @return
     */
    public static String encode(JwtUtils.T t, LoginUser user) {
//        String id = user.getId().toString();
//        String key = RandomStringUtils.randomAlphabetic(16);
//        redisTemplate.boundValueOps(t.name() + id).set(key, 24, TimeUnit.HOURS);
        JwtBuilder builder = Jwts.builder();
        user.toJwt(builder);
        String jwtBuilder = builder.signWith(signatureAlgorithm, t.key)
                .claim("role", user.toRoles())
                .compact();
        return jwtBuilder;
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        redisTemplate = applicationContext.getBean(StringRedisTemplate.class);
    }

    public static void remove(LoginUser manager) {
        String id = manager.getId().toString();
        redisTemplate.delete(id);
    }
}
