package com.chilunyc.fumao.company.model;

import com.chilunyc.fumao.common.context.LoginUser;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.enums.PlaceAdminType;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.*;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import javax.persistence.Entity;
import javax.persistence.ForeignKey;
import javax.persistence.Index;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_place_admin", indexes = {
        @Index(name = "market_admin_mobile", columnList = "mobile"),
        @Index(name = "market_admin_placeId", columnList = "placeId"),
})
@EntityListeners(AuditingEntityListener.class)
public class PlaceAdmin implements Serializable, LoginUser<Long> {

    /**
     * 编号
     */
    @Id
    @Column(columnDefinition = "bigint(64)")
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 名称
     */
    @Column(columnDefinition = "varchar(64) comment '名称'")
    private String name;

    /**
     * 密码
     */
    @JsonIgnore
    @Column(columnDefinition = "varchar(32) comment '密码'")
    private String password;

    /**
     * 密码
     */
    @Column(columnDefinition = "varchar(32) comment '初始密码'")
    private String originPassword;

    /**
     * 盐值
     */
    @JsonIgnore
    @Column(columnDefinition = "varchar(32) comment '盐值'")
    private String salt;

    /**
     * 手机号
     */
    @Column(columnDefinition = "varchar(20) comment '手机号'")
    private String mobile;

    /**
     * 集团
     */
    @Column(columnDefinition = "varchar(64) comment '集团'")
    private Long companyId;

    /**
     * 集团商场
     */
    @Column(columnDefinition = "varchar(64) comment '集团商场'")
    private Long placeId;

    /**
     * 类型
     */
    @Column(columnDefinition = "int(1) comment '类型'")
    @Enumerated(EnumType.ORDINAL)
    private PlaceAdminType type;

    /**
     * 角色
     */
    @Column(columnDefinition = "varchar(64) comment '角色'")
    private Long placeAdminRoleId;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;

    @Fetch(FetchMode.JOIN)
    @ManyToOne()
    @JoinColumn(name = "companyId", referencedColumnName = "id", insertable = false, updatable = false, foreignKey = @ForeignKey(name = "none", value = ConstraintMode.NO_CONSTRAINT))
    @NotFound(action = NotFoundAction.IGNORE)
    private Company company;

    @Fetch(FetchMode.JOIN)
    @ManyToOne()
    @JoinColumn(name = "placeId", referencedColumnName = "id", insertable = false, updatable = false, foreignKey = @ForeignKey(name = "none", value = ConstraintMode.NO_CONSTRAINT))
    @NotFound(action = NotFoundAction.IGNORE)
    private Place place;

    @OneToMany(fetch = FetchType.EAGER)
    @JoinColumn(name = "placeAdminId")
    private List<PlaceAdminPermission> placeAdminPermissionList;

    @Override
    public String[] toRoles() {
        switch (type) {
            // 业务员获取权限
            case Business:
                return placeAdminPermissionList
                        .stream()
                        .map(PlaceAdminPermission::getName)
                        .collect(Collectors.toList())
                        .toArray(new String[placeAdminPermissionList.size()]);
            // 管理员所有权限
            default:
                return new String[]{AuthRoles.PlaceAdmin};
        }
    }

    @Override
    public void fromJwt(Claims claims) {
        this.id = Long.parseLong(claims.getSubject());
        this.companyId = claims.get("cid", Long.class);
        this.placeId = claims.get("pid", Long.class);
    }

    @Override
    public void toJwt(JwtBuilder claims) {
        claims.setSubject(this.id.toString());
        claims.claim("cid", this.companyId);
        claims.claim("pid", this.placeId);
    }
}
