package com.chilunyc.fumao.company.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.request.LoginRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.common.util.security.SaltHelper;
import com.chilunyc.fumao.company.model.Place;
import com.chilunyc.fumao.company.model.PlaceAdmin;
import com.chilunyc.fumao.company.model.enums.PlaceAdminType;
import com.chilunyc.fumao.company.repository.PlaceAdminPermissionRepository;
import com.chilunyc.fumao.company.repository.PlaceAdminRepository;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminAddRequest;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminEditRequest;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class PlaceAdminService {


    @Autowired
    private PlaceAdminRepository placeAdminRepository;

    @Autowired
    private PlaceAdminPermissionRepository placeAdminPermissionRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private PlaceAdminPermissionService placeAdminPermissionService;

    public Page<PlaceAdmin> page(PlaceAdminPageRequest request) {
        return placeAdminRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public PlaceAdmin find(Long id) {
        PlaceAdmin one = placeAdminRepository.findOne(id);
        return one;
    }

    public PlaceAdmin add(PlaceAdminAddRequest request) {
        if (placeAdminRepository.existsByMobile(request.getMobile())) {
            throw new SystemException("100000");
        }
        PlaceAdmin placeAdmin = new PlaceAdmin();
        String salt = SaltHelper.salt();
        BeanHelper.copyProperties(placeAdmin, request);
        placeAdmin.setOriginPassword(request.getPassword());
        placeAdmin.setSalt(salt);
        placeAdmin.setPassword(SaltHelper.exec(request.getPassword(), salt));
        placeAdmin = placeAdminRepository.save(placeAdmin);
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.新增商场管理员, placeAdmin.getId(), request);
        if (PlaceAdminType.Business.equals(request.getType()) && request.getPermissionList() != null) {
            placeAdminPermissionService.edit(placeAdmin.getId(), request.getPermissionList());
        }
        return placeAdmin;
    }

    public PlaceAdmin edit(PlaceAdminEditRequest request) {
        PlaceAdmin placeAdmin = placeAdminRepository.findOne(request.getId());
        BeanHelper.copyProperties(placeAdmin, request);
        placeAdmin = placeAdminRepository.save(placeAdmin);
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.编辑商场管理员, placeAdmin.getId(), request);
        if (PlaceAdminType.Business.equals(request.getType()) && request.getPermissionList() != null) {
            placeAdminPermissionService.edit(placeAdmin.getId(), request.getPermissionList());
        }
        return placeAdmin;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    placeAdminRepository.delete(id);
                    placeAdminPermissionRepository.deleteByPlaceAdminId(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.删除商场管理员, null, request.getIds());
    }

    public void edit(Place place, List<PlaceAdminEditRequest> placeAdminList) {
        placeAdminList
                .stream()
                .peek(placeAdminEditRequest -> {
                    placeAdminEditRequest.setPlaceId(place.getId());
                    placeAdminEditRequest.setCompanyId(place.getCompanyId());
                })
                .forEach(this::edit);
    }

    public void resetPassword(Long id, Long companyId) {
        PlaceAdmin placeAdmin = placeAdminRepository.findByIdAndCompanyId(id, companyId);
        if (placeAdmin != null) {
            placeAdmin.setPassword(SaltHelper.exec(placeAdmin.getOriginPassword(), placeAdmin.getSalt()));
            placeAdminRepository.save(placeAdmin);
        }
    }

    public PlaceAdmin login(LoginRequest request) {
        PlaceAdmin placeAdmin = placeAdminRepository.findByMobile(request.getMobile());
        if (placeAdmin != null &&
                SaltHelper.isEquals(placeAdmin.getPassword(), request.getPassword(), placeAdmin.getSalt())) {
            return placeAdmin;
        }
        throw new SystemException("000004");
    }

    public List<PlaceAdmin> all(PlaceAdminPageRequest request) {
        return placeAdminRepository.findAll(QueryBuilder.build(request));
    }


}
