package com.chilunyc.fumao.company.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.NodeResponse;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.company.model.Place;
import com.chilunyc.fumao.company.model.PlaceFloor;
import com.chilunyc.fumao.company.repository.PlaceFloorRepository;
import com.chilunyc.fumao.company.request.placeFloor.PlaceFloorEditRequest;
import com.chilunyc.fumao.company.request.placeFloor.PlaceFloorPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 *
 */
@Log4j
@Service
@Transactional
public class PlaceFloorService {


    @Autowired
    private PlaceFloorRepository placeFloorRepository;

    @Autowired
    private EventService eventService;

    public Page<PlaceFloor> page(PlaceFloorPageRequest request) {
        return placeFloorRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public PlaceFloor find(Long id) {
        PlaceFloor one = placeFloorRepository.findOne(id);
        return one;
    }


    public PlaceFloor edit(PlaceFloorEditRequest request) {
        PlaceFloor placeFloor = new PlaceFloor();
        BeanHelper.copyProperties(placeFloor, request);
        placeFloor = placeFloorRepository.save(placeFloor);
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.编辑商场楼层, placeFloor.getId(), request);
        return placeFloor;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    placeFloorRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.删除商场楼层, null, request.getIds());
    }


    public void edit(Place place, List<PlaceFloorEditRequest> placeFloorList) {
        placeFloorList.stream()
                .peek(placeFloor -> placeFloor.setPlaceId(place.getId()))
                .forEach(this::edit);
    }

    public List<PlaceFloor> all(PlaceFloorPageRequest request) {
        return placeFloorRepository.findAll(QueryBuilder.build(request));
    }

    public List<NodeResponse> group(PlaceFloorPageRequest request) {
        List<PlaceFloor> all = all(request);
        List<NodeResponse> r = new ArrayList<>();
        all
                .stream()
                .collect(Collectors.groupingBy(PlaceFloor::getTower))
                .forEach((k, v) -> {
                    r.add(
                            new NodeResponse(k, k,
                                    v
                                            .stream()
                                            .map(f -> new NodeResponse(f.getFloor() + "", f.getTower() + "", null))
                                            .collect(Collectors.toList())
                            )
                    );
                });
        return r;
    }
}
