package com.chilunyc.fumao.company.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.company.model.Place;
import com.chilunyc.fumao.company.repository.PlaceFloorRepository;
import com.chilunyc.fumao.company.repository.PlaceRepository;
import com.chilunyc.fumao.company.request.place.PlaceEditRequest;
import com.chilunyc.fumao.company.request.place.PlacePageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class PlaceService {


    @Autowired
    private PlaceRepository placeRepository;

    @Autowired
    private PlaceFloorRepository placeFloorRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private PlaceFloorService placeFloorService;

    @Autowired
    private PlaceAdminService placeAdminService;

    public Page<Place> page(PlacePageRequest request) {
        return placeRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public Place find(Long id) {
        Place one = placeRepository.findOne(id);
        return one;
    }


    public Place edit(PlaceEditRequest request) {
        Place place = new Place();
        BeanHelper.copyProperties(place, request);
        String[] region = request.getRegion();
        place.setProvince(region[0]);
        place.setCity(region[1]);
        place.setArea(region[2]);
        place = placeRepository.save(place);

        // 处理楼层, 全部清掉, 冲洗加
        if (request.getPlaceFloorList() != null) {
            placeFloorRepository.deleteAllInBatch();
            placeFloorService.edit(place, request.getPlaceFloorList());
        }

        // 处理管理员
        if (request.getPlaceAdminList() != null) {
            placeAdminService.edit(place, request.getPlaceAdminList());
        }

        eventService.add(RequestHolder.get(), EventTarget.System, EventType.编辑商场, place.getId(), request);
        return place;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    placeRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.删除商场, null, request.getIds());
    }


    public List<Place> all(PlacePageRequest request) {
        if (request == null) {
            request = new PlacePageRequest();
        }
        List<Place> all = placeRepository.findAll(QueryBuilder.build(request));
        return all;
    }


    public void edit(List<PlaceEditRequest> marketList) {
        marketList.forEach(this::edit);
    }
}
