package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.place.model.enums.CouponKind;
import com.chilunyc.fumao.place.model.enums.CouponSendWay;
import com.chilunyc.fumao.place.model.enums.CouponStatus;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_coupon", indexes = {
})
@EntityListeners(AuditingEntityListener.class)
public class Coupon implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 封面
     */
    @Column(columnDefinition = "text comment '封面'")
    private String cover;

    /**
     * 名称
     */
    @Column(columnDefinition = "varchar(30) comment '名称'")
    private String title;

    /**
     * 副标题
     */
    @Column(columnDefinition = "varchar(50) comment '副标题'")
    private String subTitle;

    /**
     * 库存
     */
    @Column(columnDefinition = "int(9) comment '库存'")
    private Long stock;

    /**
     * 发劵方式
     */
    @Column(columnDefinition = "int(1) comment '发劵方式'")
    @Enumerated(EnumType.ORDINAL)
    private CouponSendWay sendWay;

    /**
     * 限领
     */
    @Column(columnDefinition = "text comment '限领'")
    private Integer maxNum;

    /**
     * 发放开始日期
     */
    @Column(columnDefinition = "date comment '发放开始日期'")
    private Date openFrom;

    /**
     * 发放结束日期
     */
    @Column(columnDefinition = "date comment '发放结束日期'")
    private Date openEnd;

    /**
     * 有效开始日期
     */
    @Column(columnDefinition = "date comment '有效开始日期'")
    private Date validFrom;

    /**
     * 有效结束日期
     */
    @Column(columnDefinition = "date comment '有效结束日期'")
    private Date validEnd;

    /**
     * 有效日
     */
    @Column(columnDefinition = "text comment '有效日'")
    private Integer validDay;

    /**
     * 使用须知
     */
    @Column(columnDefinition = "text comment '使用须知'")
    private String description;

    /**
     * 状态
     */
    @Column(columnDefinition = "int(1) comment '状态'")
    @Enumerated(EnumType.ORDINAL)
    private CouponStatus status;

    /**
     * 商户
     */
    @Column(columnDefinition = "bigint(64) comment '商户'")
    private Long merchantId;

    /**
     * 剩余库存
     */
    @Column(columnDefinition = "int(9) comment '使用库存'")
    private Long remain;

    /**
     * 类型
     */
    @Column(columnDefinition = "int(1) comment '类型'")
    @Enumerated(EnumType.ORDINAL)
    private CouponKind kind;

    /**
     * 商场
     */
    @Column(columnDefinition = "bigint(64) comment '商场'")
    private Long placeId;

    /**
     *
     */
    @Column(columnDefinition = "double(9,2) comment '面额'")
    private Double amount;

    /**
     *
     */
    @Column(columnDefinition = "double(9,2) comment '售价'")
    private Double requireAmount;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;


}
