package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.place.model.enums.CouponPutWay;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_coupon_channel", indexes = {
        @Index(name = "coupon_channel_couponId", columnList = "couponId"),
        @Index(name = "coupon_channel_channel", columnList = "channel"),
        @Index(name = "coupon_channel_placeId", columnList = "placeId"),
        @Index(name = "coupon_channel_cate", columnList = "cate")
})
@EntityListeners(AuditingEntityListener.class)
public class CouponChannel implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 优惠卷
     */
    @Column(columnDefinition = "bigint(64) comment '优惠卷'")
    private Long couponId;

    /**
     * 渠道
     */
    @Column(columnDefinition = "int(1) comment '渠道'")
    @Enumerated(EnumType.ORDINAL)
    private CouponPutWay channel;

    /**
     * 商场
     */
    @Column(columnDefinition = "bigint(64) comment '商场'")
    private Long placeId;

    /**
     * 分类
     */
    @Column(columnDefinition = "varchar(16) comment '分类'")
    private String cate;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;
}
