package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.place.model.enums.PlaceSettingType;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_place_setting", indexes = {
        @Index(name = "place_setting_placeId", columnList = "placeId")
})
@EntityListeners(AuditingEntityListener.class)
public class PlaceSetting implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 类型
     */
    @Column(columnDefinition = "int(1) comment '类型'")
    @Enumerated(EnumType.ORDINAL)
    private PlaceSettingType type;

    /**
     * 数值
     */
    @Column(columnDefinition = "text comment '数值'")
    private String value;

    /**
     * 商场
     */
    @Column(columnDefinition = "bigint(64) comment '商场'")
    private Long placeId;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;
}
