package com.chilunyc.fumao.place.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_point_transaction", indexes = {
        @Index(name = "point_transaction_tradeId", columnList = "tradeId"),
        @Index(name = "point_transaction_customerId", columnList = "customerId"),
        @Index(name = "point_transaction_placeId", columnList = "placeId"),
})
@EntityListeners(AuditingEntityListener.class)
public class PointTransaction implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 订单ID
     */
    @Column(columnDefinition = "varchar(32) comment '订单ID'")
    private String tradeId;

    /**
     * 客户
     */
    @Column(columnDefinition = "bigint(64) comment '客户'")
    private Long customerId;

    /**
     * 手机号
     */
    @Column(columnDefinition = "varchar(20) comment '手机号'")
    private String customerMobile;

    /**
     * 操作积分
     */
    @Column(columnDefinition = "int(9) comment '操作积分'")
    private Integer oper;

    /**
     * 原始积分
     */
    @Column(columnDefinition = "int(9) comment '原始积分'")
    private Integer origin;

    /**
     * 现在积分
     */
    @Column(columnDefinition = "int(9) comment '现在积分'")
    private Integer dest;

    /**
     * 操作人
     */
    @Column(columnDefinition = "bigint(64) comment '操作人'")
    private Long adminId;

    /**
     * 场地
     */
    @Column(columnDefinition = "bigint(64) comment '操作人'")
    private Long placeId;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;
}
