package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.place.model.enums.TradeStatus;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_trade", indexes = {
        @Index(name = "trade_couponId", columnList = "couponId"),
        @Index(name = "trade_customerId", columnList = "customerId"),
        @Index(name = "trade_shopId", columnList = "shopId"),
        @Index(name = "trade_merchantId", columnList = "merchantId"),
        @Index(name = "trade_placeId", columnList = "placeId"),
})
@EntityListeners(AuditingEntityListener.class)
public class Trade implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 优惠券
     */
    @Column(columnDefinition = "bigint(64) comment '优惠券'")
    private Long couponId;

    /**
     * 客户
     */
    @Column(columnDefinition = "bigint(64) comment '客户'")
    private Long customerId;

    /**
     * 金额
     */
    @Column(columnDefinition = "decimal(9,2) comment '金额'")
    private Double requireAmount;

    /**
     * 优惠券名称
     */
    @Column(columnDefinition = "varchar(64) comment '优惠券名称'")
    private String couponName;

    /**
     * 面额
     */
    @Column(columnDefinition = "decimal(9,2) comment '面额'")
    private Double amount;

    /**
     * 状态
     */
    @Column(columnDefinition = "int(1) comment '状态'")
    private TradeStatus status;

    /**
     * 使用时间
     */
    @Column(columnDefinition = "date comment '使用时间'")
    private Date useTime;

    /**
     * 商铺
     */
    @Column(columnDefinition = "bigint(64) comment '商铺'")
    private Long shopId;

    /**
     * 商户
     */
    @Column(columnDefinition = "bigint(64) comment '商户'")
    private Long merchantId;

    /**
     * 商场
     */
    @Column(columnDefinition = "bigint(64) comment '商场'")
    private Long placeId;

    /**
     * 过期时间
     */
    @Column(columnDefinition = "date comment '过期时间'")
    private Date expiredTime;

    /**
     * 支付时间
     */
    @Column(columnDefinition = "date comment '支付时间'")
    private Date payTime;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;
}
