package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.place.model.Coupon;
import com.chilunyc.fumao.place.model.enums.CouponStatus;
import com.chilunyc.fumao.place.repository.CouponRepository;
import com.chilunyc.fumao.place.request.coupon.CouponEditRequest;
import com.chilunyc.fumao.place.request.coupon.CouponPageRequest;
import lombok.extern.log4j.Log4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class CouponService {


    @Autowired
    private CouponRepository couponRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private CouponChannelService couponChannelService;

    public Page<Coupon> page(CouponPageRequest request) {
        return couponRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public Coupon find(Long id) {
        Coupon one = couponRepository.findOne(id);
        return one;
    }


    public List<String> cates() {
        return Arrays.asList("餐饮", "超市", "娱乐", "服装", "亲子", "鞋包", "其他");
    }

    public Coupon edit(CouponEditRequest request) {
        Coupon coupon = new Coupon();
        if (request.getId() != null) {
            coupon = couponRepository.findOne(request.getId());
        }
        BeanHelper.copyProperties(coupon, request);
        Date now = new Date();

        boolean isDraft = request.isDraft();

        // 发放日期
        Date[] open = request.getOpen();
        coupon.setOpenFrom(open[0]);
        coupon.setOpenEnd(open[1]);
        // 草稿
        if (isDraft) {
            coupon.setStatus(CouponStatus.Draft);
        }
        // 根据发放日期计算状态
        else {
            // 小于发放日期
            if (now.before(open[0])) {
                coupon.setStatus(CouponStatus.NotOpen);
            }
            // 在发放日期内
            else if (now.after(open[0]) && now.before(open[1])) {
                coupon.setStatus(CouponStatus.Open);
            }
            // 发放日期外, 无效了
            else if (now.after(open[1])) {
                coupon.setStatus(CouponStatus.Invalid);
            }
        }

        // 客户拿到优惠券的有效期
        if (StringUtils.equalsIgnoreCase(request.getValidType(), "0")) {
            Date[] valid = request.getValid();
            if (valid != null && valid.length == 2) {
                coupon.setValidFrom(valid[0]);
                coupon.setValidEnd(valid[1]);
                coupon.setValidDay(null);
            } else {
                throw new SystemException("000003", "请选择有效期");
            }
        } else {
            if (request.getValidDay() == null) {
                throw new SystemException("000003", "请输入有效日");
            }
            coupon.setValidDay(request.getValidDay());
        }

        // 使用库存
        if (coupon.getRemain() == null) {
            coupon.setRemain(0L);
        }

        // 更新优惠券分类
        couponChannelService.updateCoupon(coupon, request.getCateList());


        coupon = couponRepository.save(coupon);
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.编辑优惠券, coupon.getId(), request);
        return coupon;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    couponRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.删除优惠券, null, request.getIds());
    }

}
