package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.common.util.security.SaltHelper;
import com.chilunyc.fumao.place.model.MerchantAdmin;
import com.chilunyc.fumao.place.repository.MerchantAdminRepository;
import com.chilunyc.fumao.place.request.merchantAdmin.MerchantAdminEditRequest;
import com.chilunyc.fumao.place.request.merchantAdmin.MerchantAdminPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class MerchantAdminService {


    @Autowired
    private MerchantAdminRepository merchantAdminRepository;

    @Autowired
    private EventService eventService;

    public Page<MerchantAdmin> page(MerchantAdminPageRequest request) {
        return merchantAdminRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public MerchantAdmin find(Long id) {
        MerchantAdmin one = merchantAdminRepository.findOne(id);
        return one;
    }


    public MerchantAdmin edit(MerchantAdminEditRequest request) {
        MerchantAdmin merchantAdmin = new MerchantAdmin();
        if (request.getId() != null) {
            merchantAdmin = merchantAdminRepository.findOne(request.getId());
            merchantAdmin.setName(request.getName());
        } else {
            if (merchantAdminRepository.existsByMobile(request.getMobile())) {
                throw new SystemException("100000");
            }
            BeanHelper.copyProperties(merchantAdmin, request);
            String salt = SaltHelper.salt();
            merchantAdmin.setOriginPassword(request.getPassword());
            merchantAdmin.setSalt(salt);
            merchantAdmin.setPassword(SaltHelper.exec(request.getPassword(), salt));
        }
        merchantAdmin = merchantAdminRepository.save(merchantAdmin);
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.编辑商户管理员, merchantAdmin.getId(), request);
        return merchantAdmin;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    merchantAdminRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.删除商户管理员, null, request.getIds());
    }


    public List<MerchantAdmin> all(MerchantAdminPageRequest request) {
        return merchantAdminRepository.findAll(QueryBuilder.build(request));
    }

    public void resetPassword(Long id) {
        MerchantAdmin one = merchantAdminRepository.findOne(id);
        if (one != null) {
            one.setPassword(SaltHelper.exec(one.getOriginPassword(), one.getSalt()));
            merchantAdminRepository.save(one);
        }
    }
}
