package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.place.model.Customer;
import com.chilunyc.fumao.place.model.PointTransaction;
import com.chilunyc.fumao.place.model.enums.PlaceSettingType;
import com.chilunyc.fumao.place.model.setting.ScoreStrategySetting;
import com.chilunyc.fumao.place.repository.CustomerRepository;
import com.chilunyc.fumao.place.repository.PointTransactionRepository;
import com.chilunyc.fumao.place.request.pointTransaction.PointTransactionPaddedRequest;
import com.chilunyc.fumao.place.request.pointTransaction.PointTransactionPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 */
@Log4j
@Service
@Transactional
public class PointTransactionService {


    @Autowired
    private PointTransactionRepository pointTransactionRepository;

    @Autowired
    private CustomerRepository customerRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private CustomerService customerService;

    @Autowired
    private PlaceSettingService placeSettingService;

    public Page<PointTransaction> page(PointTransactionPageRequest request) {
        return pointTransactionRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public PointTransaction find(Long id) {
        PointTransaction one = pointTransactionRepository.findOne(id);
        return one;
    }


    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    pointTransactionRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.删除积分, null, request.getIds());
    }


    public void padded(PointTransactionPaddedRequest request) {
        //
        ScoreStrategySetting strategySetting = placeSettingService.get(request.getPlaceId(), PlaceSettingType.scoreStrategy, ScoreStrategySetting.class);
        Integer score = (int) (request.getAmount() / strategySetting.getAmount() * strategySetting.getScore());
        Customer customer = customerService.find(request.getCustomerId());
        Integer origin = customer.getScore();
        pointTransactionRepository
                .save(
                        PointTransaction
                                .builder()
                                .adminId(request.getAdminId())
                                .placeId(request.getPlaceId())
                                .customerId(request.getCustomerId())
                                .customerMobile(customer.getMobile())
                                .origin(origin)
                                .oper(score)
                                .dest(origin + score)
                                .tradeId(request.getTradeId())
                                .build()
                );

        //
        customer.setScore(score + origin);
        customerRepository.save(customer);

        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.积分补录, request.getAdminId(), request);
    }
}
