package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.AssignsRequest;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.place.model.Shop;
import com.chilunyc.fumao.place.repository.ShopRepository;
import com.chilunyc.fumao.place.request.shop.ShopEditRequest;
import com.chilunyc.fumao.place.request.shop.ShopPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class ShopService {


    @Autowired
    private ShopRepository shopRepository;

    @Autowired
    private EventService eventService;

    public Page<Shop> page(ShopPageRequest request) {
        return shopRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public Shop find(Long id) {
        Shop one = shopRepository.findOne(id);
        return one;
    }


    public Shop edit(ShopEditRequest request) {
        Shop shop = new Shop();
        if (request.getId() != null) {
            shop = shopRepository.findOne(request.getId());
        }
        BeanHelper.copyProperties(shop, request);
        String[] region = request.getRegion();
        if (region != null && region.length == 3) {
            shop.setProvince(region[0]);
            shop.setCity(region[1]);
            shop.setArea(region[2]);
        }
        shop = shopRepository.save(shop);
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.编辑商铺, shop.getId(), request);
        return shop;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    shopRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.删除商铺, null, request.getIds());
    }


    public List<Shop> all(ShopPageRequest request) {
        if (request == null) {
            request = new ShopPageRequest();
        }
        List<Shop> all = shopRepository.findAll(QueryBuilder.build(request));
        return all;
    }


    public void assign(AssignsRequest<Long> request) {
        shopRepository.updateMerchant(request.getIds(), request.getTargetId());
    }

    public void unbindMerchant(Long shopId) {
        Shop shop = shopRepository.findOne(shopId);
        if (shop != null) {
            shop.setMerchantId(null);
            shopRepository.save(shop);
        }
    }
}
